# Autogenerated by Astropy's setup.py on 2018-10-18 19:34:18 UTC
from __future__ import unicode_literals
import datetime

version = "2.0.9"
githash = "71bfbaf593761e5934293502f896528846980f80"


major = 2
minor = 0
bugfix = 9

release = True
timestamp = datetime.datetime(2018, 10, 18, 19, 34, 18)
debug = False

astropy_helpers_version = "2.0.7"

try:
    from ._compiler import compiler
except ImportError:
    compiler = "unknown"

try:
    from .cython_version import cython_version
except ImportError:
    cython_version = "unknown"
